[![flake8 Lint](https://github.com/acdh-oeaw/acdh-handle-pyutils/actions/workflows/lint.yml/badge.svg)](https://github.com/acdh-oeaw/acdh-handle-pyutils/actions/workflows/lint.yml)
[![Test](https://github.com/acdh-oeaw/acdh-handle-pyutils/actions/workflows/test.yml/badge.svg)](https://github.com/acdh-oeaw/acdh-handle-pyutils/actions/workflows/test.yml)
[![codecov](https://codecov.io/gh/acdh-oeaw/acdh-handle-pyutils/branch/master/graph/badge.svg?token=96XqlDbpDw)](https://codecov.io/gh/acdh-oeaw/acdh-handle-pyutils)
[![PyPI version](https://badge.fury.io/py/acdh-handle-pyutils.svg)](https://badge.fury.io/py/acdh-handle-pyutils)

# acdh-handle-pyutils

Utility functions to interact with handle.net API

